@@ -38,9 +38,3 @@ class SendPasswordPoint(CreatePointMixin, ContractPoint):
 class UserPoint(CreatePointMixin, ContractPoint):
     _point_id = UserID()
     _create_contract = UserCreateContract
-
-    def _get_related_points(self):
-        related_points = super()._get_related_points()
-        from expressmoney_points import sync
-        related_points.append(sync.UserPoint(self._user))
-        return related_points
